# KLL Compiler - templates

Base file templates used by emitters to generate code and other files.


## Files

Brief description of each of the files.

* [kiibohdDefs.h](kiibohdDefs.h) - Used by [kiibohd emitter](../emitters/kiibohd) to generate `kll_defs.h`.
* [kiibohdKeymap.h](kiibohdKeymap.h) - Used by [kiibohd emitter](../emitters/kiibohd) to generate `generatedKeymap.h`.
* [kiibohdPixelmap.c](kiibohdPixelmap.c) - Used by [kiibohd emitter](../emitters/kiibohd) to generate `generatedPixelmap.c`.

